Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func TemplateFS ¶
func TemplateFS(useLocal bool, logger log.Logger) http.FileSystem
TemplateFS returns a http.FileSystem for embedded assets and templates. This filesystem wraps the `github.com/mjibson/esc` API to provide a way to quickly load templates from the local file system and also use embedded files within the binary once packaged. If useLocal is true, the filesystem's content are used instead.
Types ¶
Click to show internal directories.
Click to hide internal directories.